<?php

namespace App\Http\Controllers\Api\V1;

use App\Http\Controllers\Controller;
use App\Http\Resources\AttendanceResource;
use App\Models\Attendance;
use Illuminate\Http\Request;

class AttendanceController extends Controller
{
    public function index() {
        $attendances = $this->paginateOrGet(
            Attendance::with("user", "franchise")->filter()->latest());

        return AttendanceResource::collection($attendances);
    }

    public function store(Request $request) {
        $data = $request->validate([
            'user_id' => ['required', "exists:users,id"],
            'franchise_id' => ['required', "exists:franchises,id"],
            'date_time' => ['sometimes', "date"],
            'remark' => ['sometimes', "string", "max:254"],
        ]);

        return new AttendanceResource(Attendance::create($data));
    }

    public function show(Attendance $attendance) {
        return new AttendanceResource($attendance->loadMissing("user", "franchise"));
    }

    public function update(Request $request, Attendance $attendance) {
        $data = $request->validate([
            'user_id' => ['sometimes', "exists:users,id"],
            'franchise_id' => ['sometimes', "exists:franchises,id"],
            'date_time' => ['sometimes', "date"],
            'remark' => ['sometimes', "string", "max:254"],
        ]);

        $attendance->update($data);

        return new AttendanceResource($attendance);
    }

    public function destroy(Attendance $attendance) {
        $attendance->delete();

        return response()->json(["message" => "Attendance deleted successfully!"]);
    }
}
