<?php

namespace App\Http\Controllers\Api\V1;

use App\Http\Controllers\Controller;
use App\Http\Resources\BillDetailResource;
use App\Models\BillDetail;
use Illuminate\Http\Request;

class BillDetailController extends Controller
{
    public function index() {
        $billDetails = $this->paginateOrGet(
            BillDetail::latest());

        return BillDetailResource::collection($billDetails);
    }

    public function store(Request $request) {
        $data = $request->validate([
            'user_id' => ['required', 'exists:users,id'],
            'bill_id' => ['required', 'exists:bills,id'],
            'recipe_id' => ['required', 'exists:recipes,id'],
            'qty' => ['required', "numeric", "between:0,65534"],
            'price' => ['required', 'numeric', "between:0,99999999.99"],
            'total_amount' => ['required', 'numeric', "between:0,99999999.99"],
        ]);

        return new BillDetailResource(BillDetail::create($data));
    }

    public function show(BillDetail $billDetail) {
        return new BillDetailResource($billDetail);
    }

    public function update(Request $request, BillDetail $billDetail) {
        $data = $request->validate([
            'user_id' => ['sometimes', 'exists:users,id'],
            'bill_id' => ['sometimes', 'exists:bills,id'],
            'recipe_id' => ['sometimes', 'exists:recipes,id'],
            'qty' => ['sometimes', "numeric", "between:0,65534"],
            'price' => ['sometimes', 'numeric', "between:0,99999999.99"],
            'total_amount' => ['sometimes', 'numeric', "between:0,99999999.99"],
        ]);

        $billDetail->update($data);

        return new BillDetailResource($billDetail);
    }

    public function destroy(BillDetail $billDetail) {
        $billDetail->delete();

        return response()->json();
    }
}
