<?php

namespace App\Http\Controllers\Api\V1;

use App\Http\Controllers\Controller;
use App\Models\Bill;
use App\Models\Expense;
use App\Models\PurchaseOrder;
use Carbon\Carbon;
use Illuminate\Http\JsonResponse;
use Illuminate\Http\Request;

class DashboardController extends Controller
{
    /**
     * Handle the incoming request.
     */
    public function __invoke(Request $request): JsonResponse {
        $request->validate([
            "start_date" => "required|date",
            "end_date" => "required|date",
        ]);

        $user = auth()->user();
        $franchiseId = $user->franchise_id;

        // Get and validate the start and end date from the request
        $startDate = Carbon::parse($request->input('start_date'))->startOfDay();
        $endDate = Carbon::parse($request->input('end_date'))->endOfDay();


        // function to apply common filters
        $applyFilters = fn($query) => $query->where('franchise_id', $franchiseId)
            ->when($startDate && $endDate, fn($query) => $query->whereBetween('created_at', [$startDate, $endDate]));

        // function to query and sum the amounts
        $calculateTotal = fn($model, $column) => $applyFilters($model::query())->sum($column);

        // function to get the count
        $getCount = fn($model) => $applyFilters($model::query())->count();

        // Calculate totals
        $totalBillAmount = $calculateTotal(Bill::class, 'amount');
        $totalPurchaseOrdersCost = $calculateTotal(PurchaseOrder::class, 'total');
        $totalExpensesCost = $calculateTotal(Expense::class, 'amount');

        // Calculate bill count and average order value
        $billCount = $getCount(Bill::class);
        $avgOrderValue = $billCount > 0 ? $totalBillAmount / $billCount : 0;

        // Return the calculated data as JSON
        return response()->json([
            "totalSale" => $totalBillAmount,
            "totalExpense" => $totalPurchaseOrdersCost + $totalExpensesCost,
            "averageOrderValue" => $avgOrderValue,
            "totalBill" => $totalBillAmount,
        ]);
    }
}
