<?php

namespace App\Http\Controllers\Api\V1;

use App\Http\Controllers\Controller;
use App\Http\Requests\Franchises\StoreFranchiseRequest;
use App\Http\Requests\Franchises\UpdateFranchiseRequest;
use App\Http\Resources\FranchiseResource;
use App\Http\Traits\HasStoreFile;
use App\Models\Franchise;
use App\Models\User;

class FranchiseController extends Controller
{
    use HasStoreFile;

    // path of the folder where files related to the controller will be stored
    protected string $folderPath = "franchises";

    // name of the field for file upload in the model
    protected string $fileField = "photo";


    public function index() {
        $franchises = $this->paginateOrGet(
            Franchise::with([
                "masterFranchise",
                "users",
                "items",
                "purchaseOrders"
            ])->filter()->latest());

        return FranchiseResource::collection($franchises);
    }

    public function store(StoreFranchiseRequest $request) {
        $data = $request->validated();

        $franchise = new Franchise($data);
        if ($request->hasFile($this->fileField)) {
            $franchise[$this->fileField] = $this->storeFile($request, $this->fileField, $this->folderPath);
        }
        $franchise->save();

        $franchiseUser = new User();
        $franchiseUser->fill($data);
        $franchiseUser->name = $request->user_name;
        $franchiseUser->franchise_id = $franchise->id;
        $franchiseUser->mobile_no = $request->mobile;
        $franchiseUser->role = "franchise";
        $franchiseUser->save();

        return response()->json(
            new FranchiseResource($franchise->loadMissing("users")), 201
        );
    }

    public function show(Franchise $franchise) {
        return new FranchiseResource($franchise->loadMissing([
            "users", "items", "purchaseOrders", "masterFranchise"
        ]));
    }

    public function update(UpdateFranchiseRequest $request, Franchise $franchise) {
        $data = $request->validated();

        $franchise->fill($data);
        if ($request->hasFile($this->fileField)) {
            $this->deleteFile($this->folderPath, $franchise[$this->fileField]);
            $franchise[$this->fileField] = $this->storeFile($request, $this->fileField, $this->folderPath);
        }
        $franchise->save();

        $franchiseUser = User::where("franchise_id", $franchise->id)
            ->where("role", "franchise")->first();

        if ($franchiseUser) {
            $franchiseUser->update($data);
        }

        return new FranchiseResource($franchise);
    }

    public function destroy(Franchise $franchise) {
        $this->deleteFile($this->folderPath, $franchise->photo);
        $franchise->delete();

        return response()->json(["message" => "Franchise deleted successfully!"]);
    }
}
