<?php

namespace App\Http\Controllers\Api\V1;

use App\Http\Controllers\Controller;
use App\Http\Resources\ItemResource;
use App\Http\Traits\HasStoreFile;
use App\Models\Item;
use Illuminate\Http\Request;

class ItemController extends Controller
{
    use HasStoreFile;

    // path of the folder where files related to the controller will be stored
    protected string $folderPath = "items";

    // name of the field for file upload in the model
    protected string $fileField = "image";

    public function index() {
        $items = $this->paginateOrGet(
            Item::with("franchise")->filter()->latest());

        return ItemResource::collection($items);
    }

    public function store(Request $request) {
        $data = $request->validate([
            'franchise_id' => 'required',
            'name' => 'required|string',
            'qty' => 'required|numeric|between:0,65534',
            'type' => 'required|string',
            'image' => 'nullable|file|mimes:jpeg,jpg,png,gif|max:2048',
        ]);

        $item = new Item($data);
        if ($request->hasFile($this->fileField)) {
            $item[$this->fileField] = $this->storeFile($request, $this->fileField, $this->folderPath);
        }
        $item->save();

        return response()->json(
            new ItemResource($item), 201
        );
    }

    public function show(Item $item) {
        return new ItemResource($item->loadMissing("franchise"));
    }

    public function update(Request $request, Item $item) {
        $data = $request->validate([
            'franchise_id' => 'sometimes',
            'name' => 'sometimes|string',
            'qty' => 'sometimes',
            'type' => 'sometimes|string',
            'image' => $request->hasFile("image")
                ? ["file", "mimes:jpeg,png,jpg,gif", "max:2048"]
                : ["sometimes", "string", "max:100"],
        ]);

        $item->fill($data);
        if ($request->hasFile($this->fileField)) {
            $this->deleteFile($this->folderPath, $item[$this->fileField]);
            $item[$this->fileField] = $this->storeFile($request, $this->fileField, $this->folderPath);
        }
        $item->save();

        return new ItemResource($item);
    }

    public function destroy(Item $item) {
        $this->deleteFile($this->folderPath, $item[$this->fileField]);
        $item->delete();

        return response()->json(["message" => "Item deleted successfully!"]);
    }
}
