<?php

namespace App\Http\Controllers\Api\V1;

use App\Http\Controllers\Controller;
use App\Http\Resources\ParcelDetailResource;
use App\Models\ParcelDetail;
use Illuminate\Http\Request;

class ParcelDetailController extends Controller
{
    public function index() {
        $parcelDetails = $this->paginateOrGet(
            ParcelDetail::latest());

        return ParcelDetailResource::collection($parcelDetails);
    }

    public function store(Request $request) {
        $data = $request->validate([
            'bill_id' => ['required', 'exists:bills,id'],
            'item_id' => ['required', 'exists:items,id'],
            'qty' => ['required', "numeric", "between:0,65534"],
        ]);

        return new ParcelDetailResource(ParcelDetail::create($data));
    }

    public function show(ParcelDetail $parcelDetail) {
        return new ParcelDetailResource($parcelDetail);
    }

    public function update(Request $request, ParcelDetail $parcelDetail) {
        $data = $request->validate([
            'bill_id' => ['required', 'exists:bills'],
            'item_id' => ['required', 'exists:items'],
            'qty' => ['nullable'],
        ]);

        $parcelDetail->update($data);

        return new ParcelDetailResource($parcelDetail);
    }

    public function destroy(ParcelDetail $parcelDetail) {
        $parcelDetail->delete();

        return response()->json();
    }
}
