<?php

namespace App\Http\Controllers\Api\V1;

use App\Http\Controllers\Controller;
use App\Http\Resources\PurchaseOrderResource;
use App\Models\Item;
use App\Models\PurchaseOrder;
use App\Models\PurchaseOrderDetail;
use Illuminate\Http\Request;

class PurchaseOrderController extends Controller
{
    public function index() {
        $purchaseOrders = $this->paginateOrGet(
            PurchaseOrder::with(["purchaseOrderDetails.item", "franchise",])->filter()->latest());

        return PurchaseOrderResource::collection($purchaseOrders);
    }

    public function store(Request $request) {
        $request->validate([
            "franchise_id" => ["required", "exists:franchises,id"],
            "vendor_name" => ["required", "string", "max:254"],
            "total" => ["required", "numeric", "between:0,9999999999.99"],
            "date" => ["sometimes", "date"],
            "type" => ["sometimes", "string", "max:254"],
            "paid_date" => ["sometimes", "date"],
            "is_paid" => ["required", "boolean"],
            "purchase_order_details" => ["sometimes", "array"],

            "purchase_order_details.*.item_id" => "required|exists:items,id",
            "purchase_order_details.*.qty" => "required|numeric|between:0,65534",
            "purchase_order_details.*.price" => "required|numeric|between:0,99999999.99",
        ]);

        $purchaseOrder = PurchaseOrder::query()->create(
            $request->except("purchase_order_details")
        );

        // TODO: what's going on ?
        if ($request->has("purchase_order_details")) {
            foreach ($request->purchase_order_details as $order_detail) {
                $purchaseOrderDetail = new PurchaseOrderDetail();
                $purchaseOrderDetail->fill($order_detail);
                $purchaseOrderDetail->purchase_order_id = $purchaseOrder->id;
                $purchaseOrderDetail->save();

                if ($purchaseOrder->is_paid) {
                    $item = Item::findOrFail($purchaseOrderDetail->item_id);
                    $item->qty += (int) $purchaseOrderDetail->qty;
                    $item->save();
                }
            }
        }

        return response()->json(
            new PurchaseOrderResource($purchaseOrder), 201
        );
    }

    public function show(PurchaseOrder $purchaseOrder) {
        return new PurchaseOrderResource(
            $purchaseOrder->loadMissing(["purchaseOrderDetails.item", "franchise"])
        );
    }

    public function update(Request $request, PurchaseOrder $purchaseOrder) {
        $request->validate([
            "franchise_id" => ["required", "exists:franchises,id"],
            "vendor_name" => ["required", "string", "max:254"],
            "total" => ["required", "numeric", "between:0,9999999999.99"],
            "date" => ["sometimes", "date"],
            "type" => ["sometimes", "string", "max:254"],
            "paid_date" => ["sometimes", "date"],
            "is_paid" => ["required", "boolean"],
            "purchase_order_details" => ["sometimes", "array"],

            "purchase_order_details.*.id" => "sometimes|exists:purchase_order_details,id",
            "purchase_order_details.*.item_id" => "required|exists:items,id",
            "purchase_order_details.*.qty" => "required|numeric|between:0,65534",
            "purchase_order_details.*.price" => "required|numeric|between:0,99999999.99",

            "delete_purchase_order_detail_ids" => "sometimes|array",

        ]);
        $purchaseOrder->update(
            $request->except("purchase_order_details", "delete_purchase_order_detail_ids")
        );

        if ($request->has("purchase_order_details")) {
            foreach ($request->purchase_order_details as $order_detail) {
                // Update purchase order detail if it exists already
                if (!isset($order_detail["id"])) {
                    $purchaseOrderDetail = PurchaseOrderDetail::findOrFail($order_detail->id);
//                    $oldQty = $purchaseOrderDetail->qty;
                    $purchaseOrderDetail->fill($order_detail);
                    $purchaseOrderDetail->purchase_order_id = $purchaseOrder->id;
                    $purchaseOrderDetail->save();

                    if ($purchaseOrder->is_paid) {
                        $item = Item::findOrFail($purchaseOrderDetail->item_id);
                        $item->qty += (int) $purchaseOrderDetail->qty;
                        $item->save();
                    }
                } else {
                    // else: create new purchase order detail model
                    $purchaseOrderDetail = new PurchaseOrderDetail;
                    $purchaseOrderDetail->fill($order_detail);
                    $purchaseOrderDetail->purchase_order_id = $purchaseOrder->id;

                    if ($purchaseOrder->is_paid) {
                        $item = Item::findOrFail($purchaseOrderDetail->item_id);
                        $item->qty += (int) $purchaseOrderDetail->qty;
                        $item->save();
                    }
                }
            }
        }

        if ($request->has("delete_purchase_order_detail_ids")) {
            foreach ($request->delete_purchase_order_detail_ids as $id) {
                $purchaseOrderDetail = PurchaseOrderDetail::findOrFail($id);
                $item = Item::findOrFail($purchaseOrderDetail->item_id);
                $item->qty -= $purchaseOrderDetail->qty;
                $item->save();
            }
            PurchaseOrderDetail::query()->whereIn("id", $request->delete_purchase_order_detail_ids)->delete();
        }

        return new PurchaseOrderResource($purchaseOrder);
    }

    public function destroy(PurchaseOrder $purchaseOrder) {
        PurchaseOrderDetail::where("purchase_order_id", $purchaseOrder->id)->delete();
        $purchaseOrder->delete();

        return response()->json(["message" => "Purchase Order deleted successfully!"]);
    }
}
