<?php

namespace App\Http\Controllers\Api\V1;

use App\Http\Controllers\Controller;
use App\Http\Resources\SupportResource;
use App\Models\Support;
use Illuminate\Http\Request;

class SupportController extends Controller
{
    public function index() {
        $supports = $this->paginateOrGet(
            Support::latest());

        return SupportResource::collection($supports);
    }

    public function store(Request $request) {
        $data = $request->validate([
            'user_id' => ['required', 'exists:users,id'],
            'subject' => ['required', "string", "max:254"],
            'remarks' => ['required', "string", "max:254"],
            'image' => ['sometimes', "file", "mimes:jpg,jpeg,png,gif", "max:2048"],
        ]);

        return new SupportResource(Support::create($data));
    }

    public function show(Support $support) {
        return new SupportResource($support);
    }

    public function update(Request $request, Support $support) {
        $data = $request->validate([
            'user_id' => ['sometimes', 'exists:users,id'],
            'subject' => ['sometimes', "string", "max:254"],
            'remarks' => ['sometimes', "string", "max:254"],
            'image' => $request->hasFile("image")
                ? ["file", "mimes:jpg,jpeg,png,gif", "max:2048"]
                : ["sometimes", "string", "max:100"],
        ]);

        $support->update($data);

        return new SupportResource($support);
    }

    public function destroy(Support $support) {
        $support->delete();

        return response()->json();
    }
}
