<?php

namespace App\Http\Controllers\Api\V1;

use App\Http\Controllers\Controller;
use App\Http\Resources\TicketResource;
use App\Http\Traits\HasStoreFile;
use App\Models\Ticket;
use Illuminate\Http\Request;

class TicketController extends Controller
{
    use HasStoreFile;

    public function index() {
        $tickets = $this->paginateOrGet(
            Ticket::with(["franchise", "user"])->latest());

        return TicketResource::collection($tickets);
    }

    public function store(Request $request) {
        $data = $request->validate([
            'user_id' => ['required', 'exists:users,id'],
            'franchise_id' => ['required', 'exists:franchises,id'],
            'subject' => ['required', "string", "max:254"],
            'message' => ['sometimes', "string", "max:254"],
            'file' => ['nullable', "file", "mimes:jpg,jpeg,png,pdf", "max:2048"],
            'resolved_date' => ['nullable', "date"],
            'remarks' => ['nullable', "string", "max:254"],
        ]);

        $ticket = new Ticket($data);
        if ($request->hasFile("file")) {
            $ticket->file = $this->storeFile($request, "file", "tickets");
        }
        $ticket->save();

        return new TicketResource($ticket);
    }

    public function show(Ticket $ticket) {
        return new TicketResource($ticket->loadMissing(["franchise", "user"]));
    }

    public function update(Request $request, Ticket $ticket) {
        $data = $request->validate([
            'user_id' => ['sometimes', 'exists:users,id'],
            'franchise_id' => ['sometimes', 'exists:franchises,id'],
            'subject' => ['sometimes', "string", "max:254"],
            'message' => ['sometimes', "string", "max:254"],
            'file' => $request->hasFile("file")
                ? ["file", "mimes:png,jpg,jpeg,pdf", "max:2048"]
                : ["sometimes", "string", "max:100"],
            'resolved_date' => ['sometimes', "date"],
            'remarks' => ['sometimes', "string", "max:254"],
        ]);

        if ($request->hasFile("file")) {
            $this->deleteFile("tickets", $ticket->file);
            $data["file"] = $this->storeFile($request, "file", "tickets");
        }

        $ticket->update($data);

        return new TicketResource($ticket);
    }

    public function destroy(Ticket $ticket) {
        $this->deleteFile("tickets", $ticket->file);
        $ticket->delete();

        return response()->json();
    }
}
