<?php

namespace App\Http\Controllers\Api\V1;

use App\Http\Controllers\Controller;
use App\Http\Resources\UserResource;
use App\Models\User;
use Illuminate\Http\Request;

class UserController extends Controller
{
    public function index() {
        $users = $this->paginateOrGet(
            User::with("franchise")->filter()->latest());

        return UserResource::collection($users);
    }

    public function store(Request $request) {
        $data = $request->validate([
            'master_franchise_id' => 'sometimes|exists:master_franchises,id',
            'franchise_id' => 'sometimes|exists:franchises,id',
            "mobile_no" => 'required|string',
            'name' => 'required|string|max:254',
            'email' => 'required|email|max:254',
            'password' => 'required|confirmed|string',
            'password_confirmation' => "required",
            'role' => 'required|string|max:50',
            'designation' => 'required|string|max:50',
            "status" => "sometimes|boolean",
            "city" => "sometimes|string|max:50",
            "country" => "sometimes|string|max:50",
            "pincode" => "sometimes|string|max:20",
            "is_customer" => "sometimes|boolean",
            "is_customer_registered" => "sometimes|boolean",
            "is_blacklisted" => "sometimes|boolean",
        ]);

        return response()->json(
            new UserResource(User::create($data)), 201
        );
    }

    public function show(User $user) {
        return new UserResource($user->loadMissing("franchise"));
    }

    public function update(Request $request, User $user) {
        $request->validate([
            'master_franchise_id' => 'sometimes|exists:master_franchises,id',
            'franchise_id' => 'sometimes|exists:franchises,id',
            "mobile_no" => 'sometimes|string',
            'name' => 'sometimes|string|max:254',
            'email' => 'sometimes|email|max:254',
            'password' => 'sometimes|string',
            'role' => 'sometimes|string|max:50',
            'designation' => 'sometimes|string|max:50',
            "status" => "sometimes|boolean",
            "city" => "sometimes|string|max:50",
            "country" => "sometimes|string|max:50",
            "pincode" => "sometimes|string|max:20",
            "is_customer" => "sometimes|boolean",
            "is_customer_registered" => "sometimes|boolean",
            "is_blacklisted" => "sometimes|boolean",
        ]);

        $user->update($request->all());

        return new UserResource($user);
    }

    public function destroy(User $user) {
        $user->delete();

        return response()->json(["message" => "User deleted successfully!"]);
    }
}
