<?php

namespace App\Http\Requests\Franchises;

use Illuminate\Foundation\Http\FormRequest;

class StoreFranchiseRequest extends FormRequest
{
    /**
     * Determine if the user is authorized to make this request.
     */
    public function authorize(): bool {
        return true;
    }

    /**
     * Get the validation rules that apply to the request.
     *
     * @return array<string, \Illuminate\Contracts\Validation\ValidationRule|array<mixed>|string>
     */
    public function rules(): array {
        $rules = [
            'master_franchise_id' => ['required', "exists:master_franchises:id"],
            'shop_name' => ['required', "max:254"],
            'user_name' => ['required', "max:254"],
            'email' => ['required', 'email', "unique:franchises,email", "unique:users,email", 'max:25'],
            'mobile' => ['required', "string", "max:254"],
            'password' => ["required", "string", "confirmed"],
            'password_confirmation' => ["required"],
            'address' => ['nullable', "string", "max:254"],
            'landmark' => ['nullable', "string", "max:254"],
            'city' => ['required', "string", "max:50"],
            'country' => ['required', "string", "max:50"],
            'state' => ['nullable', "max:50"],
            'pincode' => ['required', "string", "max:20"],
            'gst' => ['nullable', "string", "max:20"],
            'cgst' => ['nullable', "string", "max:20"],
            'photo' => ['sometimes', "file", "mimes:jpeg,png,jpg,gif", "max:2048"],
            'user_contact' => ['nullable', "string", "max:20"],
            'user_dob' => ['nullable', "date"],
            'shop_opening_date' => ['nullable', "date"],
            'franchise_amount' => ['nullable', "numeric", "between:0,9999999999.99"],
            'master_commission_percent' => ['nullable', "numeric", "between:0,101"],
            'renewal_date' => ['nullable', "date"],
            "role" => ["nullable", "string"],
            'is_master' => ['boolean'],
            'is_active' => ['boolean'],
            'is_approved' => ['boolean'],
        ];

        return $rules;

    }
}
