<?php

namespace Database\Seeders;

use App\Models\Franchise;
use App\Models\Item;
use App\Models\MasterFranchise;
use App\Models\Recipe;
use App\Models\RecipeDetail;
use App\Models\Table;
use App\Models\User;
use Illuminate\Database\Seeder;

// use Illuminate\Database\Console\Seeds\WithoutModelEvents;

class DatabaseSeeder extends Seeder
{
    /**
     * Seed the application's database.
     */
    public function run(): void {

        User::factory()->create([
            "name" => "Udit Takwani",
            "email" => "admin@pos.com",
            "role" => "admin",
        ]);

        // create a master franchise
        $masterFranchise = MasterFranchise::factory()->create();

        foreach (range(1, 4) as $index) {
            $franchise = Franchise::factory()->create([
                "shop_name" => "Test franchise $index",
                "master_franchise_id" => $masterFranchise->id,
                "is_master" => $index === 1,
            ]);

            // create a franchise employee
            $userEmployee = User::factory()->create([
                "role" => "employee",
                "master_franchise_id" => $masterFranchise->id,
                "franchise_id" => $franchise->id
            ]);

            if ($index !== 1) {
                continue;
            }

            $item = Item::factory()->create([
                "franchise_id" => $franchise->id,
            ]);

            $recipe = Recipe::factory()->create([
                "franchise_id" => $franchise->id,
            ]);
            $recipeDetail = RecipeDetail::factory()->create([
                "recipe_id" => $recipe->id,
                "item_id" => $item->id,
            ]);

            foreach (range(1, 3) as $tableIndex) {
                $table = Table::factory()->create([
                    "franchise_id" => $franchise->id,
                ]);
            }
        }
    }
}
