<?php

use App\Http\Controllers\Api\V1\AttendanceController;
use App\Http\Controllers\Api\V1\AuthController;
use App\Http\Controllers\Api\V1\BillController;
use App\Http\Controllers\Api\V1\DashboardController;
use App\Http\Controllers\Api\V1\ExpenseController;
use App\Http\Controllers\Api\V1\ExpenseTypeController;
use App\Http\Controllers\Api\V1\FranchiseController;
use App\Http\Controllers\Api\V1\InventoryOrderController;
use App\Http\Controllers\Api\V1\InventoryReturnController;
use App\Http\Controllers\Api\V1\ItemController;
use App\Http\Controllers\Api\V1\MasterFranchiseController;
use App\Http\Controllers\Api\V1\OrderSourceController;
use App\Http\Controllers\Api\V1\PaymentTypeController;
use App\Http\Controllers\Api\V1\PurchaseOrderController;
use App\Http\Controllers\Api\V1\RecipeController;
use App\Http\Controllers\Api\V1\StatsController;
use App\Http\Controllers\Api\V1\TableController;
use App\Http\Controllers\Api\V1\TicketController;
use App\Http\Controllers\Api\V1\TicketReplyController;
use App\Http\Controllers\Api\V1\UserController;
use Illuminate\Support\Facades\Route;

Route::prefix('v1')->group(function () {
    Route::post('register', [AuthController::class, 'register']);
    Route::post('login', [AuthController::class, 'login']);
    Route::post('forget-password', [AuthController::class, 'forgetPassword']);
    Route::post('update-password', [AuthController::class, 'updatePassword']);

    Route::middleware("auth:sanctum")
        ->namespace("App\Http\Controllers\Api\V1")
        ->group(function () {
            Route::apiResources([
                "franchise-masters" => MasterFranchiseController::class,
                "franchises" => FranchiseController::class,
                "users" => UserController::class,
                "items" => ItemController::class,
                "expense-types" => ExpenseTypeController::class,
                "expenses" => ExpenseController::class,
                "tables" => TableController::class,
                "order-sources" => OrderSourceController::class,
                "payment-types" => PaymentTypeController::class,
                "purchase-orders" => PurchaseOrderController::class,
                "inventory-orders" => InventoryOrderController::class,
                "inventory-returns" => InventoryReturnController::class,
                "recipes" => RecipeController::class,
                "attendances" => AttendanceController::class,
                "bills" => BillController::class,
                "tickets" => TicketController::class,
                "ticket-replies" => TicketReplyController::class,
            ]);
            Route::get("dashboard", DashboardController::class)->name("dashboard");

            Route::get("counts", [StatsController::class, "counts"]);
            Route::post("offline-bills", [BillController::class, "offlineBills"]);
        });
});
